@@ -62,10 +62,10 @@ sub installable {
     my $template = 0;
     my $unindented_list = 0;
 
-    # description?
-    my $full_description = $processable->fields->value('Description');
     return
-      unless length $full_description;
+      unless $processable->fields->exists('Description');
+
+    my $full_description = $processable->fields->value('Description');
 
     $self->tag('odd-mark-in-description', 'comma not followed by whitespace')
       if $full_description =~ /,\S/;
@@ -232,7 +232,7 @@ sub installable {
     # Check for a package homepage in the description and no Homepage
     # field.  This is less accurate and more of a guess than looking
     # for the old Homepage: convention in the body.
-    unless ($processable->fields->value('Homepage') or $flagged_homepage) {
+    unless ($processable->fields->exists('Homepage') or $flagged_homepage) {
         if (
             $extended =~ /homepage|webpage|website|url|upstream|web\s+site
                          |home\s+page|further\s+information|more\s+info
