@@ -28,7 +28,8 @@ use Exporter qw(import);
 use Carp qw(croak);
 use Dpkg::Vendor;
 
-use Lintian::Util qw(check_path safe_qx);
+use Lintian::IO::Async qw(safe_qx);
+use Lintian::Util qw(check_path);
 
 our @EXPORT_OK= qw(check_test_feature default_parallel split_tag
   sanitize_environment open_file_or_fd);
