@@ -19,12 +19,14 @@
 
 package Lintian::Processable::Patched;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Path::Tiny;
 
+use Lintian::Index::Item;
 use Lintian::Index::Patched;
 
 use Moo::Role;
@@ -96,8 +98,6 @@ question).
 Third, hardlinking information is lost and no attempt has been made
 to restore it.
 
-Needs-Info requirements for using I<index>: unpacked
-
 =cut
 
 sub index {
@@ -125,10 +125,10 @@ sub sorted_index {
 =item index_resolved_path(PATH)
 
 Resolve PATH (relative to the root of the package) and return the
-L<entry|Lintian::File::Path> denoting the resolved path.
+L<entry|Lintian::Index::Item> denoting the resolved path.
 
 The resolution is done using
-L<resolve_path|Lintian::File::Path/resolve_path([PATH])>.
+L<resolve_path|Lintian::Index::Item/resolve_path([PATH])>.
 
 =cut
 
